Skip to contents

Generate a summary report of the taxonomy of a taxa rank

Usage

report_taxonomy(x, top = 5)

Arguments

x

A data frame or tibble containing the frequency information of the taxa rank. It must have columns 'n' and 'freq'. This dataframe typically generated from taxonomic_cov()

top

The number of top taxa to include in the report. Default value is 5.

Value

A character string representing the generated report.

Details

This function generates a report based on the input data frame 'x' containing frequency information of certain taxa rank. It provides information about the most represented taxa.

Examples

# Example usage
data(borreguiles)
# Calculate taxonomic coverage for scientificName and genus
d <- taxonomic_cov(borreguiles, category = c("scientificName", "genus"))
# Generate report
report_taxonomy(d$genus)
#>   There are 52 genus included in the dataset. The 5 genus most represented in the dataset are: Carex (16.58 %), Nardus (9.35 %), Scorzoneroides (9 %), Gentiana (8.8 %) and Euphrasia (6.47 %).
#>